Learn R Programming

nlmeU (version 0.70-3)

Pwr: Calculates power based on a model fit

Description

This function is generic; method functions can be written to handle specific classes of objects.

Usage

Pwr(object, ...)

Arguments

object

an object containing the results returned by a model fitting function (e.g., lme).

some methods for this generic function may require additional arguments.

Value

numeric scalar value.

See Also

Pwr.lme

Examples

Run this code
# NOT RUN {
  Pwr (fm1)
# }

Run the code above in your browser using DataLab