Data from Age-Related Macular Degeneration (ARMD) clinical trial
The armd.wide data frame has 240 rows and 10 columns. Data are
stored in wide format with each row corresponding to one subject.
a factor with 240 levels 1, 2, 3, 4, 5, ..., 240
an integer vector with values 1, 2, 3, 4
an integer vector with values ranging from 5 to 17
an integer vector with values of visual acuity measured at baseline ranging from 20 to 85
an integer vector with values of visual acuity measured at 4 weeks ranging from 12 to 84
an integer vector with values of visual acuity measured at 12 weeks ranging from 3 to 85
an integer vector with values of visual acuity measured at 24 weeks ranging from 5 to 85
an integer vector with values of visual acuity measured at 52 weeks from 4 to 85
a factor with 2 levels Placebo, Active
a factor with 9 levels ----, ---X, --X-, --XX, -XX-, ...,XXXX
The ARMD data arise from a randomized multi-center clinical trial comparing an experimental treatment (interferon-alpha) versus placebo for patients diagnosed with ARMD.
armd, armd0