Learn R Programming

nlmeU (version 0.70-3)

fcat: fcat Data (4851 x 3)

Description

Data from Flemish Community Attainment-Targets (FCAT) Study

Arguments

Format

The fcat data frame has 4851 rows and 3 columns

target

a factor with 9 levels T1(4), T2(6), T3(8), T4(5), T5(9), ..., T9(5)

id

a factor with 539 levels 1, 2, 3, 4, 5, ..., 539

scorec

an integer vector with values from 0 to 9

Details

An educational study, in which elementary school graduates were evaluated with respect to reading comprehension in Dutch. Pupils from randomly selected schools were assessed for a set of nine attainment targets. The dataset is an example of grouped data, for which the grouping factors are crossed.

Examples

Run this code
# NOT RUN {
summary(fcat)
# }

Run the code above in your browser using DataLab