Learn R Programming

nlmeU (version 0.70-9)

logLik1: Calculates contribution of one subject to the log-likelihood

Description

This function is generic; method functions can be written to handle specific classes of objects.

Usage

logLik1(modfit, dt1, dtInit)

Value

numeric scalar value representing contribution of a given subject to the overall log-likelihood returned by

logLik() function.

Arguments

modfit

an object representing model fitted to data using ML estimation.

dt1

a data frame with data for one subject, for whom the log-likelihood function is to be evaluated

dtInit

an optional auxiliary data frame.

Author

Andrzej Galecki and Tomasz Burzykowski

References

???

Examples

Run this code
require(nlme)
  logLik(fm1 <- lme(distance ~ age, data = Orthodont)) # random is ~ age
  dt1 <- subset(Orthodont, Subject == "M01")
  logLik1(fm1, dt1)

Run the code above in your browser using DataLab