Learn R Programming

nlmeU (version 0.71.7)

nlmeU-package: nlmeU: Datasets and Utility Functions Enhancing Functionality of 'nlme' Package

Description

Provides functions and datasets to support the book by Galecki and Burzykowski (2013), "Linear Mixed-Effects Models Using R: A Step-by-Step Approach", Springer. Package includes functions for power calculations, log-likelihood contributions, and data simulation for linear mixed-effects models.

Arguments

Author

Maintainer: Andrzej T. Galecki agalecki@umich.edu (ORCID)

Authors:

Details

This package provides datasets and utility functions to complement the nlme package, including functions like logLik1, Pwr, and simulateY. It also includes datasets such as armd, armd0, armd.wide, fcat, prt.fiber, prt, prt.subjects, and SIIdata.

See Also