Learn R Programming

nlmeU (version 0.70-3)

prt: prt Data (2471 x 9)

Description

Data from a Progressive Resistance Randomized Trial.

Arguments

Format

The prt data frame has 2471 rows and 9 columns. It contains data for n = 63 subjects. Each subject underwent muscle biopsy before and after intervention. Data are stored in a long format with each record corresponding to one muscle fiber. There are two types of muscle fibers: Type 1 and Type 2. Dependent variables: specific force and isometric force are measured pre- and post intervention.

id

a factor with 63 levels 5, 10, 15, 20, 25, ..., 520 (subject id)

prt.f

a factor with 2 levels High, Low, i.e. training (intervention) intensity

age.f

a factor with 2 levels Young, Old (stratifying variable)

sex.f

a factor with 2 levels Female, Male (stratifying variable)

bmi

a numeric vector with values of BMI at baseline ranging from 18.36 to 32.29

iso.fo

a numeric vector with values of isometric force ranging from 0.16 to 2.565

spec.fo

a numeric vector with values of specific force ranging from 80.5 to 290

occ.f

a factor with 2 levels Pre, Pos, i.e. pre- and post-intervention.

fiber.f

a factor with 2 levels Type 1, Type 2, i.e. Type 1 and Type 2 muscle fiber.

Details

Data frame prt was obtained by merging prt.subjects and prt.fiber.

See Also

prt.fiber, prt.subjects

Examples

Run this code
# NOT RUN {
summary(prt)
# }

Run the code above in your browser using DataLab