Learn R Programming

nlmeU (version 0.70-3)

prt.fiber: prt.fiber Data (2471 x 5)

Description

Data from a Progressive Resistance Randomized Trial.

Arguments

Format

The prt.fiber data frame has 2471 rows and 5 columns. Each row in the data corresponds to one muscle fiber collected during muscle biopsy. See prt data frame for the description of the study design.

id

a factor with 63 levels 5, 10, 15, 20, 25, ..., 520

iso.fo

a numeric vector with values of isometric force ranging from 0.16 to 2.565

spec.fo

a numeric vector with values of specific force ranging from 80.5 to 290

occ.f

a factor with 2 levels Pre, Pos, i.e. pre- and post- intervention

fiber.f

a factor with 2 levels Type 1, Type 2, i.e. Type 1 and Type 2 muscle fiber.

Details

PRT trial was aimed for devising evidence-based methods for improving and measuring the mobility and muscle power of elderly men and women

See Also

prt, prt.subjects

Examples

Run this code
# NOT RUN {
summary(prt.fiber)
# }

Run the code above in your browser using DataLab