Learn R Programming

nlmeU (version 0.71.7)

prt.subjects: prt.subjects Data (63 x 5)

Description

Data from a Progressive Resistance Randomized Trial.

Usage

prt.subjects

Arguments

Format

A data frame with 63 rows and 5 columns:

id

A factor with 63 levels: 5, 10, 15, 20, 25, ...

prt.f

A factor with 2 levels: High, Low

age.f

A factor with 2 levels: Young, Old

sex.f

A factor with 2 levels: Female, Male

bmi

A numeric vector with values from 18.4 to 32.3

Details

The working hypothesis was that a 12-week program of PRT would increase: (a) the power output of the overall musculature associated with movements of the ankles, knees, and hips; (b) the cross-sectional area and the force and power of permeabilized single fibers obtained from the vastus lateralis muscle; and (c) the ability of young and elderly men and women to safely arrest standardized falls. The training consisted of repeated leg extensions by shortening contractions of the leg extensor muscles against a resistance that was increased as the subject trained using a specially designed apparatus.

Examples

Run this code
data(prt.subjects, package = "nlmeU")
summary(prt.subjects)

Run the code above in your browser using DataLab