powered by
This function is generic; method functions can be written to handle specific classes of objects.
sigma(object, ...)
an object for which scale parameter can be extracted.
some methods for this generic function may require additional arguments.
numeric scalar value.
# NOT RUN { ## sigma (fm1) # }
Run the code above in your browser using DataLab