Learn R Programming

nlmeU (version 0.71.7)

simulateY.lme: Simulates values for an lme object

Description

This is a method for the simulateY generic function.

Usage

# S3 method for lme
simulateY(
  object,
  nsim = 1,
  seed = as.integer(runif(1, 0, .Machine$integer.max)),
  ...,
  verbose = FALSE,
  sigma
)

Value

Numeric matrix with the number of columns determined by the nsim argument.

Arguments

object

an lme object with a model fit for which the dependent variable is to be simulated.

nsim

number of simulations. By default, nsim = 1.

seed

integer scalar used to initiate the random number generator.

...

some methods for this generic function may require additional arguments.

verbose

logical. If TRUE, basic information about arguments is provided. By default set to FALSE.

sigma

numeric scalar. Allows simulations employing an alternative value of the scale parameter.

Author

Andrzej Galecki and Tomasz Burzykowski

Details

Simulates values of the dependent variable for a fitted lme model. Data with one level of grouping only.

Examples

Run this code

if (FALSE) {
  library(nlme)
  fm1 <- lme(distance ~ age, data = Orthodont)
  simulateY(fm1)
}

Run the code above in your browser using DataLab