powered by
This function is generic; method functions can be written to handle specific classes of objects.
Pwr(object, ...)
an object containing the results returned by a model fitting function (e.g., lme).
lme
some methods for this generic function may require additional arguments.
numeric scalar value.
Pwr.lme
# NOT RUN { Pwr (fm1) # }
Run the code above in your browser using DataLab