powered by
This function is generic; method functions can be written to handle specific classes of objects.
Pwr(object, ...)
numeric scalar value.
an object containing the results returned by a model fitting function (e.g., lme).
lme
some methods for this generic function may require additional arguments.
Andrzej Galecki and Tomasz Burzykowski
Pwr.lme
if (FALSE) { Pwr (fm1) }
Run the code above in your browser using DataLab