Learn R Programming

nlmeU (version 0.71.7)

Pwr: Calculates power based on a model fit

Description

This function is generic; method functions can be written to handle specific classes of objects.

Usage

Pwr(object, ...)

Value

Numeric scalar value.

Arguments

object

an object containing the results returned by a model fitting function (e.g., lme).

...

some methods for this generic function may require additional arguments.

Author

Andrzej Galecki and Tomasz Burzykowski

References

Galecki, A., & Burzykowski, T. (2013). *Linear Mixed-Effects Models: A Step-by-Step Approach*. Springer.

See Also

Pwr.lme

Examples

Run this code
if (FALSE) {
  library(nlme)
  fm1 <- lme(distance ~ age, data = Orthodont)
  Pwr(fm1)
}

Run the code above in your browser using DataLab