powered by
This function is generic; method functions can be written to handle specific classes of objects.
Pwr(object, ...)
Numeric scalar value.
an object containing the results returned by a model fitting function (e.g., lme).
lme
some methods for this generic function may require additional arguments.
Andrzej Galecki and Tomasz Burzykowski
Galecki, A., & Burzykowski, T. (2013). *Linear Mixed-Effects Models: A Step-by-Step Approach*. Springer.
Pwr.lme
if (FALSE) { library(nlme) fm1 <- lme(distance ~ age, data = Orthodont) Pwr(fm1) }
Run the code above in your browser using DataLab