Learn R Programming

nlmeU (version 0.71.7)

armd.wide: armd.wide Data (240 x 10)

Description

Data from Age-Related Macular Degeneration (ARMD) clinical trial

Usage

armd.wide

Arguments

Format

A data frame with 240 rows and 10 columns:

subject

A factor with 240 levels: 1, 2, 3, 4, 5, ..., 240

lesion

An integer vector with values 1, 2, 3, 4

line0

An integer vector with values ranging from 5 to 17

visual0

An integer vector with values of visual acuity measured at baseline ranging from 20 to 85

visual4

An integer vector with values of visual acuity measured at 4 weeks ranging from 12 to 84

visual12

An integer vector with values of visual acuity measured at 12 weeks ranging from 3 to 85

visual24

An integer vector with values of visual acuity measured at 24 weeks ranging from 5 to 85

visual52

An integer vector with values of visual acuity measured at 52 weeks from 4 to 85

treat.f

A factor with 2 levels: Placebo, Active

miss.pat

A factor with 9 levels: ----, ---X, --X-, --XX, -XX-, ..., XXXX

Details

The ARMD data arise from a randomized multi-center clinical trial comparing an experimental treatment (interferon-alpha) versus placebo for patients diagnosed with ARMD.

See Also

armd, armd0

Examples

Run this code
data(armd.wide, package = "nlmeU")
summary(armd.wide)

Run the code above in your browser using DataLab