Learn R Programming

nlmeU (version 0.71.7)

fcat: fcat Data (4851 x 3)

Description

Data from Flemish Community Attainment-Targets (FCAT) Study

Usage

fcat

Arguments

Format

A data frame with 4851 rows and 3 columns:

target

A factor with 9 levels: T1(4), T2(6), T3(8), T4(5), T5(9), ..., T9(5)

id

A factor with 539 levels: 1, 2, 3, 4, 5, ..., 539

scorec

An integer vector with values from 0 to 9

Details

An educational study, in which elementary school graduates were evaluated with respect to reading comprehension in Dutch. Pupils from randomly selected schools were assessed for a set of nine attainment targets. The dataset is an example of grouped data, for which the grouping factors are crossed.

Examples

Run this code
data(fcat, package = "nlmeU")
summary(fcat)

Run the code above in your browser using DataLab