powered by
This function is generic; method functions can be written to handle specific classes of objects.
logLik1(modfit, dt1, dtInit)
numeric scalar value representing contribution of a given subject to the overall log-likelihood returned by
logLik() function.
logLik()
an object representing model fitted to data using ML estimation.
a data frame with data for one subject, for whom the log-likelihood function is to be evaluated
an optional auxiliary data frame.
Andrzej Galecki and Tomasz Burzykowski
???
require(nlme) logLik(fm1 <- lme(distance ~ age, data = Orthodont)) # random is ~ age dt1 <- subset(Orthodont, Subject == "M01") logLik1(fm1, dt1)
Run the code above in your browser using DataLab