Data from a Progressive Resistance Randomized Trial.
The prt data frame has 2471 rows and 9 columns. It contains
data for n = 63 subjects. Each subject underwent muscle biopsy before and
after intervention. Data are stored in a long format with each record
corresponding to one muscle fiber. There are two types of muscle fibers: Type
1 and Type 2. Dependent variables: specific force and isometric force are
measured pre- and post intervention.
a factor with 63 levels 5, 10, 15, 20, 25, ..., 520 (subject id)
a factor with 2 levels High, Low, i.e. training (intervention) intensity
a factor with 2 levels Young, Old (stratifying variable)
a factor with 2 levels Female, Male (stratifying variable)
a numeric vector with values of BMI at baseline ranging from 18.36 to 32.29
a numeric vector with values of isometric force ranging from 0.16 to 2.565
a numeric vector with values of specific force ranging from 80.5 to 290
a factor with 2 levels Pre, Pos, i.e. pre- and post-intervention.
a factor with 2 levels Type 1, Type 2, i.e. Type 1 and Type 2 muscle fiber.
Data frame prt was obtained by merging
prt.subjects and prt.fiber.
prt.fiber, prt.subjects