Learn R Programming

nlmeU (version 0.71.7)

prt: prt Data (2471 x 9)

Description

Data from a Progressive Resistance Randomized Trial.

Usage

prt

Arguments

Format

A data frame with 2471 rows and 9 columns:

id

A factor with 63 levels: 5, 10, 15, 20, 25, ..., 520 (subject id)

prt.f

A factor with 2 levels: High, Low, i.e., training (intervention) intensity

age.f

A factor with 2 levels: Young, Old (stratifying variable)

sex.f

A factor with 2 levels: Female, Male (stratifying variable)

bmi

A numeric vector with values of BMI at baseline ranging from 18.36 to 32.29

iso.fo

A numeric vector with values of isometric force ranging from 0.16 to 2.565

spec.fo

A numeric vector with values of specific force ranging from 80.5 to 290

occ.f

A factor with 2 levels: Pre, Pos, i.e., pre- and post-intervention

fiber.f

A factor with 2 levels: Type 1, Type 2, i.e., Type 1 and Type 2 muscle fiber

Details

Data frame prt was obtained by merging prt.subjects and prt.fiber.

See Also

prt.fiber, prt.subjects

Examples

Run this code
data(prt, package = "nlmeU")
summary(prt)

Run the code above in your browser using DataLab