- id
a factor with 63 levels 5, 10, 15, 20, 25, ..., 520
- iso.fo
a numeric vector with values of isometric force ranging from 0.16 to 2.565
- spec.fo
a numeric vector with values of specific force ranging from 80.5 to 290
- occ.f
a factor with 2 levels Pre, Pos, i.e. pre- and post- intervention
- fiber.f
a factor with 2 levels Type 1, Type 2, i.e. Type 1 and Type 2 muscle fiber.