Learn R Programming

nlmeU (version 0.71.7)

prt.fiber: prt.fiber Data (2471 x 5)

Description

Data from a Progressive Resistance Randomized Trial.

Usage

prt.fiber

Arguments

Format

A data frame with 2471 rows and 5 columns:

id

A factor with 63 levels: 5, 10, 15, 20, 25, ..., 520

iso.fo

A numeric vector with values of isometric force ranging from 0.16 to 2.565

spec.fo

A numeric vector with values of specific force ranging from 80.5 to 290

occ.f

A factor with 2 levels: Pre, Pos, i.e., pre- and post-intervention

fiber.f

A factor with 2 levels: Type 1, Type 2, i.e., Type 1 and Type 2 muscle fiber

Details

PRT trial was aimed for devising evidence-based methods for improving and measuring the mobility and muscle power of elderly men and women.

See Also

prt, prt.subjects

Examples

Run this code
data(prt.fiber, package = "nlmeU")
summary(prt.fiber)

Run the code above in your browser using DataLab