powered by
This function is generic; method functions can be written to handle specific classes of objects.
sigma(object, ...)
numeric scalar value.
an object for which scale parameter can be extracted.
some methods for this generic function may require additional arguments.
Andrzej Galecki and Tomasz Burzykowski
## sigma (fm1)
Run the code above in your browser using DataLab