powered by
lme
This is a method for the simulateY generic function.
simulateY
# S3 method for lme simulateY( object, nsim = 1, seed = as.integer(runif(1, 0, .Machine$integer.max)), ..., verbose = FALSE, sigma )
Numeric matrix with the number of columns determined by the nsim argument.
nsim
an lme object with a model fit for which the dependent variable is to be simulated.
number of simulations. By default, nsim = 1.
nsim = 1
integer scalar used to initiate the random number generator.
some methods for this generic function may require additional arguments.
logical. If TRUE, basic information about arguments is provided. By default set to FALSE.
TRUE
FALSE
numeric scalar. Allows simulations employing an alternative value of the scale parameter.
Andrzej Galecki and Tomasz Burzykowski
Simulates values of the dependent variable for a fitted lme model. Data with one level of grouping only.
if (FALSE) { library(nlme) fm1 <- lme(distance ~ age, data = Orthodont) simulateY(fm1) }
Run the code above in your browser using DataLab